==> sympy.keras-1.0.21.tar.gz: sympy.keras-1.0.21/sympy/functions/__init__.py <==
"""A functions module, includes all the standard functions.

Combinatorial - factorial, fibonacci, harmonic, bernoulli...
Elementary - hyperbolic, trigonometric, exponential, floor and ceiling, sqrt...
Special - gamma, zeta,spherical harmonics...
"""

from sympy.functions.combinatorial.factorials import (factorial, factorial2,
        rf, ff, binomial, RisingFactorial, FallingFactorial, subfactorial, Factorial, Factorial2)

from sympy.functions.combinatorial.factorials import Binomial

from sympy.functions.combinatorial.numbers import (carmichael, fibonacci, lucas, tribonacci,
        harmonic, bernoulli, bell, euler, catalan, genocchi, partition, Stirling)
from sympy.core.power import sqrt, cbrt, root, real_root
from sympy.functions.elementary.miscellaneous import (Min, Max, Id)
from sympy.functions.elementary.complexes import (Re, Im, sign, Sign, Abs, Norm,
        Conjugate, conjugate, Arg, arg, polar_lift, periodic_argument, unbranched_argument,
        principal_branch, polarify, unpolarify)
from sympy.functions.elementary.trigonometric import (sin, cos, tan, 
        sec, csc, cot, sinc, asin, acos, atan, asec, acsc, acot, atan2)

from sympy.functions.elementary.trigonometric import Sin, Cos, Tan, Sec, Csc, Cot, ArcSin, ArcCos, ArcTan, ArcSec, ArcCsc, ArcCot

from sympy.functions.elementary.exponential import (exp_polar, exp, log, Exp, Log,
        LambertW)
from sympy.functions.elementary.hyperbolic import (sinh, cosh, tanh, coth,
        sech, csch, asinh, acosh, atanh, acoth, asech, acsch)
from sympy.functions.elementary.integers import floor, ceiling, frac, Floor, Ceiling, FractionalPart
from sympy.functions.elementary.piecewise import Piecewise, piecewise_fold, ExprCondPair
from sympy.functions.special.error_functions import (erf, erfc, erfi, erf2,
        erfinv, erfcinv, erf2inv, Ei, expint, E1, li, Li, Si, Ci, Shi, Chi,
        fresnels, fresnelc)
from sympy.functions.special.gamma_functions import (gamma, lowergamma,
        uppergamma, polygamma, loggamma, digamma, trigamma, multigamma)
from sympy.functions.special.zeta_functions import (dirichlet_eta, zeta,
        lerchphi, polylog, stieltjes)
from sympy.functions.special.tensor_functions import (Eijk, LeviCivita,
        KroneckerDelta, Bool)
from sympy.functions.special.singularity_functions import SingularityFunction
from sympy.functions.special.delta_functions import DiracDelta, Heaviside
from sympy.functions.special.bsplines import bspline_basis, bspline_basis_set, interpolating_spline
from sympy.functions.special.bessel import (besselj, bessely, besseli, besselk,
        hankel1, hankel2, jn, yn, jn_zeros, hn1, hn2, airyai, airybi, airyaiprime, airybiprime)
from sympy.functions.special.hyper import hyper, meijerg, appellf1
from sympy.functions.special.polynomials import (legendre, assoc_legendre,
        hermite, chebyshevt, chebyshevu, chebyshevu_root, chebyshevt_root,
        laguerre, assoc_laguerre, gegenbauer, jacobi, jacobi_normalized)
from sympy.functions.special.spherical_harmonics import Ynm, Ynm_c, Znm
from sympy.functions.special.elliptic_integrals import (elliptic_k,
        elliptic_f, elliptic_e, elliptic_pi)
from sympy.functions.special.beta_functions import beta
from sympy.functions.special.mathieu_functions import (mathieus, mathieuc,
        mathieusprime, mathieucprime)
ln = log

==> sympy.keras-1.0.23.tar.gz: sympy.keras-1.0.23/sympy/functions/__init__.py <==
"""A functions module, includes all the standard functions.

Combinatorial - factorial, fibonacci, harmonic, bernoulli...
Elementary - hyperbolic, trigonometric, exponential, floor and ceiling, sqrt...
Special - gamma, zeta,spherical harmonics...
"""

from sympy.functions.combinatorial.factorials import (factorial, factorial2,
        rf, ff, binomial, RisingFactorial, FallingFactorial, subfactorial, Factorial, Factorial2)

from sympy.functions.combinatorial.factorials import Binomial, Multinomial

from sympy.functions.combinatorial.numbers import (carmichael, fibonacci, lucas, tribonacci,
        harmonic, bernoulli, bell, euler, catalan, genocchi, partition, Stirling, Stirling1)
from sympy.core.power import sqrt, cbrt, root, real_root
from sympy.functions.elementary.miscellaneous import (Min, Max, Id)
from sympy.functions.elementary.complexes import (Re, Im, sign, Sign, Abs, Norm,
        Conjugate, conjugate, Arg, arg, polar_lift, periodic_argument, unbranched_argument,
        principal_branch, polarify, unpolarify)
from sympy.functions.elementary.trigonometric import (sin, cos, tan, 
        sec, csc, cot, sinc, asin, acos, atan, asec, acsc, acot, atan2)

from sympy.functions.elementary.trigonometric import Sin, Cos, Tan, Sec, Csc, Cot, ArcSin, ArcCos, ArcTan, ArcSec, ArcCsc, ArcCot

from sympy.functions.elementary.exponential import (exp_polar, exp, log, Exp, Log,
        LambertW)
from sympy.functions.elementary.hyperbolic import (sinh, cosh, tanh, coth,
        sech, csch, asinh, acosh, atanh, acoth, asech, acsch)
from sympy.functions.elementary.integers import floor, ceiling, frac, Floor, Ceiling, FractionalPart
from sympy.functions.elementary.piecewise import Piecewise, piecewise_fold, ExprCondPair
from sympy.functions.special.error_functions import (erf, erfc, erfi, erf2,
        erfinv, erfcinv, erf2inv, Ei, expint, E1, li, Li, Si, Ci, Shi, Chi,
        fresnels, fresnelc)
from sympy.functions.special.gamma_functions import (gamma, lowergamma,
        uppergamma, polygamma, loggamma, digamma, trigamma, multigamma)
from sympy.functions.special.zeta_functions import (dirichlet_eta, zeta,
        lerchphi, polylog, stieltjes)
from sympy.functions.special.tensor_functions import (Eijk, LeviCivita,
        KroneckerDelta, Bool)
from sympy.functions.special.singularity_functions import SingularityFunction
from sympy.functions.special.delta_functions import DiracDelta, Heaviside
from sympy.functions.special.bsplines import bspline_basis, bspline_basis_set, interpolating_spline
from sympy.functions.special.bessel import (besselj, bessely, besseli, besselk,
        hankel1, hankel2, jn, yn, jn_zeros, hn1, hn2, airyai, airybi, airyaiprime, airybiprime)
from sympy.functions.special.hyper import hyper, meijerg, appellf1
from sympy.functions.special.polynomials import (legendre, assoc_legendre,
        hermite, chebyshevt, chebyshevu, chebyshevu_root, chebyshevt_root,
        laguerre, assoc_laguerre, gegenbauer, jacobi, jacobi_normalized)
from sympy.functions.special.spherical_harmonics import Ynm, Ynm_c, Znm
from sympy.functions.special.elliptic_integrals import (elliptic_k,
        elliptic_f, elliptic_e, elliptic_pi)
from sympy.functions.special.beta_functions import beta
from sympy.functions.special.mathieu_functions import (mathieus, mathieuc,
        mathieusprime, mathieucprime)
ln = log
